<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       tatvic.com
 * @since      1.0.0
 *
 * @package    Enhanced_Ecommerce_Google_Analytics
 * @subpackage Enhanced_Ecommerce_Google_Analytics/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Enhanced_Ecommerce_Google_Analytics
 * @subpackage Enhanced_Ecommerce_Google_Analytics/admin
 * @author     Tatvic
 */

class Enhanced_Ecommerce_Google_Analytics_Admin extends TVC_Admin_Helper {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since      1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    protected $ga_id;
    protected $ga_LC;
    protected $ga_eeT;
    protected $site_url;
    protected $pro_plan_site;
    protected $google_detail;
    public function __construct($plugin_name, $version) {                       
        $this->plugin_name = $plugin_name;
        $this->version = $version;
        $this->url = $this->get_onboarding_page_url();
        $this->site_url = "admin.php?page=conversios";
        $this->pro_plan_site = $this->get_pro_plan_site();
        $this->google_detail = $this->get_ee_options_data();
        //remove container_old_ui_head hook once new UI all implemented
        //add_action('container_old_ui_head',array($this,'create_head'));
    }
    public function tvc_admin_notice(){
        // add fixed message notification
        $this->add_tvc_fixed_nofification();
        $ee_additional_data = $this->get_ee_additional_data();
        if(isset($ee_additional_data['dismissed_ee_adimin_notic_a']) && $ee_additional_data['dismissed_ee_adimin_notic_a'] == 1){
        }else{
          if(!$this->get_subscriptionId()){          
            echo '<div class="notice notice-info is-dismissible" data-id="ee_adimin_notic_a">
                  <p>'. __("Tatvic EE plugin is now fully compatible with Google Analytics 4. Also, explore the new features of Google Shopping and Dynamic remarketing to reach million of shoppers across Google and scale your eCommerce business faster.","conversios").' <a href="admin.php?page=conversios"><b><u>'. __("CONFIGURE NOW","conversios").'</u></b></a></p>
                 </div>'; 
          }
        }
        if(isset($ee_additional_data['dismissed_ee_adimin_notic_b']) && $ee_additional_data['dismissed_ee_adimin_notic_b'] == 1){
        }else{
            $google_detail = $this->get_ee_options_data();
            if(isset($google_detail['setting']) && $google_detail['setting']){
                $googleDetail = $google_detail['setting'];
                if(isset($googleDetail->google_merchant_center_id) && $googleDetail->google_merchant_center_id =="" && $this->subscriptionId != "" ){
                    echo '<div class="notice notice-info is-dismissible" data-id="ee_adimin_notic_b">
                      <p>'. __("Leverage the power of Google Shopping to reach out millions of shoppers across Google. Automate entire Google Shopping and get eligible for free listing when user searches on Google for products similar to your eCommerce business.","conversios").' <a href="admin.php?page=conversios"><b><u>'. __("Automate now","conversios").'</u></b></a></p>
                     </div>';
                     
                }
            } 
        }
        if(isset($ee_additional_data['dismissed_ee_adimin_notic_c']) && $ee_additional_data['dismissed_ee_adimin_notic_c'] == 1){
        }else{
          echo '<div class="notice notice-info is-dismissible" data-id="ee_adimin_notic_c">
                <p>'. __("Now access important eCommerce KPIs and Google Ads campaign performance data directly in your wordpress backend to improve your marketing ROI.","conversios").' <a href="admin.php?page=conversios"><b><u>'. __("View it from here.","conversios").'</u></b></a></p>
               </div>';
          
        }
        ?>
        <script>
          var tvc_ajax_url = '<?php echo admin_url( 'admin-ajax.php' ); ?>';
          (function( $ ) {
            $( function() {
              $( '.notice' ).on( 'click', '.notice-dismiss', function( event, el ) {
                var ee_notice_dismiss_id = $(this).parent('.is-dismissible').attr("data-id");
                jQuery.post(tvc_ajax_url,{
                    action: "tvc_call_notice_dismiss",
                    data:{ee_notice_dismiss_id:ee_notice_dismiss_id},
                    dataType: "json"
                },function( response ){                            
                });
              });
            });
          })( jQuery );
         </script>
        <?php       
    }

    
    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {
      $screen = get_current_screen();
      if ($screen->id == 'toplevel_page_conversios'  || (isset($_GET['page']) && strpos($_GET['page'], 'conversios') !== false) ) {
          if($_GET['page'] == "conversios_onboarding"){
            return;
          }
          wp_register_style('plugin-bootstrap', esc_url(ENHANCAD_PLUGIN_URL . '/includes/setup/plugins/bootstrap/css/bootstrap.min.css') );
          wp_enqueue_style('plugin-bootstrap');          
          wp_enqueue_style('custom-css', esc_url(ENHANCAD_PLUGIN_URL . '/admin/css/custom-style.css'), array(), $this->version, 'all' );
          //if(is_rtl()){  }
          if($this->is_current_tab_in(array('sync_product_page','gaa_config_page'))){
              wp_register_style('plugin-select2', esc_url(ENHANCAD_PLUGIN_URL . '/includes/setup/plugins/select2/select2.min.css') );
              wp_enqueue_style('plugin-select2');
              wp_register_style('plugin-steps', esc_url(ENHANCAD_PLUGIN_URL . '/includes/setup/plugins/jquery-steps/jquery.steps.css'));
              wp_enqueue_style('plugin-steps');
              wp_register_style('tvc-dataTables-css', esc_url(ENHANCAD_PLUGIN_URL.'/admin/css/dataTables.bootstrap4.min.css'));
              wp_enqueue_style('tvc-dataTables-css');
          }
          if($this->is_current_tab_in(array("shopping_campaigns_page","add_campaign_page"))){
            
            wp_register_style('plugin-select2', esc_url(ENHANCAD_PLUGIN_URL . '/includes/setup/plugins/select2/select2.min.css') );
            wp_enqueue_style('plugin-select2');
            wp_register_style('tvc-bootstrap-datepicker-css', esc_url(ENHANCAD_PLUGIN_URL. '/includes/setup/plugins/datepicker/bootstrap-datepicker.min.css'));
            wp_enqueue_style('tvc-bootstrap-datepicker-css');
          }
          wp_enqueue_style($this->plugin_name, esc_url(plugin_dir_url(__FILE__) . 'css/enhanced-ecommerce-google-analytics-admin.css'), array(), $this->version, 'all');
      }
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {
      $screen = get_current_screen();
      if ($screen->id == 'toplevel_page_conversios'  || (isset($_GET['page']) && strpos($_GET['page'], 'conversios') !== false) ) {
          if($_GET['page'] == "conversios_onboarding"){
            return;
          }
          wp_enqueue_script( 'custom-jquery', esc_url(ENHANCAD_PLUGIN_URL . '/admin/js/jquery-3.5.1.min.js'), array( 'jquery' ), $this->version, false );
          wp_register_script('popper_bootstrap', esc_url(ENHANCAD_PLUGIN_URL . '/admin/js/popper.min.js') );
          wp_enqueue_script('popper_bootstrap');
          wp_register_script('atvc_bootstrap', esc_url(ENHANCAD_PLUGIN_URL . '/admin/js/bootstrap.min.js') );
          wp_enqueue_script('atvc_bootstrap');
          //wp_register_script('tvc_bootstrap_mod', 'https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta2/dist/js/bootstrap.bundle.min.js');
          //wp_enqueue_script('tvc_bootstrap_mod');
         
          wp_enqueue_script( 'tvc-ee-custom-js', esc_url(ENHANCAD_PLUGIN_URL . '/admin/js/tvc-ee-custom.js'), array( 'jquery' ), $this->version, false );

          wp_enqueue_script( 'tvc-ee-slick-js', esc_url(ENHANCAD_PLUGIN_URL . '/admin/js/slick.min.js'), array( 'jquery' ), $this->version, false );
          
          if($this->is_current_tab_in(array('sync_product_page','gaa_config_page'))){
            wp_register_script('plugin-select2', esc_url(ENHANCAD_PLUGIN_URL . '/includes/setup/plugins/select2/select2.min.js') );
            wp_enqueue_script('plugin-select2');
            wp_register_script('plugin-step-js', esc_url(ENHANCAD_PLUGIN_URL . '/includes/setup/plugins/jquery-steps/jquery.steps.js') );
            wp_enqueue_script('plugin-step-js');
          }
          if($this->is_current_tab_in(array('sync_product_page'))){
            wp_enqueue_script( 'tvc-ee-dataTables-js', esc_url(ENHANCAD_PLUGIN_URL . '/admin/js/jquery.dataTables.min.js'), array( 'jquery' ), $this->version, false );
            wp_enqueue_script( 'tvc-ee-dataTables-1-js', esc_url(ENHANCAD_PLUGIN_URL . '/admin/js/dataTables.bootstrap4.min.js'), array( 'jquery' ), $this->version, false );
          }
          if($this->is_current_tab_in(array("shopping_campaigns_page","add_campaign_page"))){
            wp_register_script('plugin-select2', esc_url(ENHANCAD_PLUGIN_URL . '/includes/setup/plugins/select2/select2.min.js') );
            wp_enqueue_script('plugin-select2');
            wp_register_script('plugin-chart', esc_url(ENHANCAD_PLUGIN_URL . '/includes/setup/plugins/chart/chart.js'));
            wp_enqueue_script('plugin-chart');
            wp_register_script('tvc-bootstrap-datepicker-js', esc_url(ENHANCAD_PLUGIN_URL . '/includes/setup/plugins/datepicker/bootstrap-datepicker.min.js'));
            wp_enqueue_script('tvc-bootstrap-datepicker-js');
          }
      }
    }
}
